import Task from "./task.js"
import TaskView from "./view.js"
import DetailTaskView from "./detail_view.js"

class TaskController {
  constructor(){
    this.tasks = []
    this.task_views = []

    this.list_element = document.querySelector("task-list")
    this.detail_view = new DetailTaskView(document.querySelector("task-detail"))

    this.addButton = document.querySelector('#add_button')
    this.addButton.addEventListener("click", () => {
      this.addTask(new Task({done: false, description: "New Task"}))
    })
  }

  addTask(task){
    let view = new TaskView(task)
    view.element.addEventListener("click", () => this.detail_view.task = task )
    this.list_element.appendChild(view.element)
    this.task_views.push(view)

    task.addEventListener("change", () => this.save(task))
  }

  async refresh(){
    let tasks_response = await fetch("/tasks", {method: "GET"})
    let tasks_data = await tasks_response.json()
  
    for (let task_data of tasks_data){ this.tasks.push(new Task(task_data)) }
    for (let task of this.tasks){ this.addTask(task) }
  }

  async save(task){
    let tasks_response = await fetch(`/tasks/${task.id}`, {
      method: "PUT",
      body: JSON.stringify(task.data),
      headers: {
        'Content-Type': 'application/json'
      }
    })
  }
}

export default TaskController